#!/usr/bin/env bash

: '

ENV VARS:
    CONFIG
    OUTPUT_DIR_BASE
    TRUTH_TSV
    AUDIO_DIR
    SCORING_ADJMAP_FILE

./scripts/run.sh <config-file> <output> <truth-tsv> <audio-dir> <adjmap-file>

e.g. 
    ./scripts/run.sh config.json ./output ./samples/16khz_media/truth.tsv ./samples/16khz_media/audio/wav ./samples/16khz_media/mappings.adjmap

'

PYTHON=python

CONFIG=${CONFIG:-./config.json}
OUTPUT_DIR_BASE=${OUTPUT_DIR_BASE:-./output}
TRUTH_TSV=${TRUTH_TSV:-./truth.tsv}
AUDIO_DIR=${AUDIO_DIR:-./audio}
SCORING_ADJMAP_FILE=${SCORING_ADJMAP_FILE:-./mappings.adjmap}

if [ -n "$1" ];
then
    CONFIG=${1}
fi
if [ -n "$2" ];
then
    OUTPUT_DIR_BASE=${2}
fi
if [ -n "$3" ];
then
    TRUTH_TSV=${3}
fi
if [ -n "$4" ];
then
    AUDIO_DIR=${4}
fi
if [ -n "$5" ];
then
    SCORING_ADJMAP_FILE=${5}
fi

OUTPUT_DIR=${OUTPUT_DIR_BASE}/$(date +"%Y.%m.%d-%H.%M.%S")
RUNNER_LOG_FILE=${OUTPUT_DIR}/log.txt
VALIDATION_LOG_FILE=${OUTPUT_DIR}/test_set_validation.log
RAW_RESULTS_TSV=${OUTPUT_DIR}/results.tsv 
RESULTS_SCORED_TSV=${OUTPUT_DIR}/results.nuanscored.tsv

mkdir -p $OUTPUT_DIR

echo ""
echo "Running with"
echo " -> CONFIG ${CONFIG}"
echo " -> RUNNER_LOG_FILE ${RUNNER_LOG_FILE}"
echo " -> VALIDATION_LOG_FILE ${VALIDATION_LOG_FILE}"
echo " -> TRUTH_TSV ${TRUTH_TSV}"
echo " -> AUDIO_DIR ${AUDIO_DIR}"
echo " -> OUTPUT_DIR ${OUTPUT_DIR}"
echo " -> RAW_RESULTS_TSV ${RAW_RESULTS_TSV}"
echo " -> RESULTS_SCORED_TSV ${RESULTS_SCORED_TSV}"
echo " -> SCORING_ADJMAP_FILE ${SCORING_ADJMAP_FILE}"
echo ""

$PYTHON -m nuance.validation \
    --config $CONFIG \
    --truth_tsv $TRUTH_TSV \
    --audio_file_path $AUDIO_DIR \
    --log $VALIDATION_LOG_FILE

if [[ $? -ne 0 ]] ; then
    echo ""
    echo "Test set validation failed."
    echo "See $VALIDATION_LOG_FILE for details."
    echo ""
    echo "To re-run:
$PYTHON -m nuance.validation \
    --config $CONFIG \
    --truth_tsv $TRUTH_TSV \
    --audio_file_path $AUDIO_DIR \
    --log $VALIDATION_LOG_FILE"
    exit 1
fi

$PYTHON -m nuance.testaccuracy \
    -c $CONFIG \
    -t $TRUTH_TSV \
    -a $AUDIO_DIR \
    -o $OUTPUT_DIR \
    --log $RUNNER_LOG_FILE

if [[ $? -ne 0 ]] ; then
    echo ""
    echo "Tests failed."
    echo ""
    exit 1
else
    echo "To re-run:
$PYTHON -m nuance.testaccuracy \
    -c $CONFIG \
    -t $TRUTH_TSV \
    -a $AUDIO_DIR \
    -o $OUTPUT_DIR \
    --log $RUNNER_LOG_FILE"
fi

$PYTHON -m nuance.score \
    --csvref $TRUTH_TSV \
    --csvhyp $RAW_RESULTS_TSV \
    --map $SCORING_ADJMAP_FILE \
    --out $OUTPUT_DIR \
    --runtimeConfig $CONFIG

if [[ $? -ne 0 ]] ; then
    echo ""
    echo "Scoring failed."
    echo ""
    exit 1
else
    echo "To re-run:
$PYTHON -m nuance.score \
    --csvref $TRUTH_TSV \
    --csvhyp $RAW_RESULTS_TSV \
    --map $SCORING_ADJMAP_FILE \
    --out $OUTPUT_DIR \
    --runtimeConfig $CONFIG"
fi

$PYTHON -m nuance.report \
    $RESULTS_SCORED_TSV \
    $CONFIG \
    $OUTPUT_DIR

if [[ $? -ne 0 ]] ; then
    echo ""
    echo "Report generation failed."
    echo ""
    exit 1
else
    echo "To re-run:
$PYTHON -m nuance.report \
    $RESULTS_SCORED_TSV \
    $CONFIG \
    $OUTPUT_DIR"
fi

echo "Run complete."
echo ""
echo "open $OUTPUT_DIR/report.html"
echo ""
